@@ -27,7 +27,9 @@ impl<A: ?Sized> Dupe for &A {}
 impl<A: ?Sized> Dupe for *const A {}
 impl<A: ?Sized> Dupe for *mut A {}
 impl<A: ?Sized> Dupe for Arc<A> {}
+impl<A: ?Sized> Dupe for std::sync::Weak<A> {}
 impl<A: ?Sized> Dupe for Rc<A> {}
+impl<A: ?Sized> Dupe for std::rc::Weak<A> {}
 impl<A: Copy> Dupe for Cell<A> {}
 
 // Small containers
@@ -82,6 +84,7 @@ impl Dupe for std::net::SocketAddrV6 {}
 impl Dupe for std::thread::ThreadId {}
 impl Dupe for std::time::Instant {}
 impl Dupe for std::time::SystemTime {}
+impl Dupe for std::time::Duration {}
 impl<T: ?Sized> Dupe for std::marker::PhantomData<T> {}
 
 impl<R> Dupe for fn() -> R {}
