@@ -30,6 +30,10 @@ pub mod variants;
 mod test;
 
 /// Causes Rust to exit the process when any panic occurs.
+#[deprecated(
+    since = "0.4.2",
+    note = "Compiling with -Cpanic=abort provides similar behavior and smaller binaries"
+)]
 pub fn terminate_on_panic() {
     let orig_hook = std::panic::take_hook();
     std::panic::set_hook(Box::new(move |panic_info| {
